@@ -185,7 +185,7 @@ static unsigned char revalidate_path(const char *path)
 	return type;
 }
 
-/* File handle to /etc/tomoyo/current/policy/exception_policy.conf . */
+/* File handle to /etc/tomoyo/policy/current/exception_policy.conf . */
 static FILE *filp = NULL;
 
 /**
@@ -1515,15 +1515,15 @@ static const char notifyd_data[] =
 "#\n"
 "# action_to_take is a command line you want to use for notification.\n"
 "# The command specified by this parameter must read the policy violation\n"
-"# notifycation from standard input. For example, mail, curl and xmessage\n"
+"# notification from standard input. For example, mail, curl and xmessage\n"
 "# commands can read from standard input.\n"
 "# This parameter is passed to execve(). Thus, please use a wrapper program\n"
 "# if you need shell processing (e.g. wildcard expansion, environment\n"
 "# variables).\n"
 "#\n"
 "# minimal_interval is grace time in second before re-notifying the next\n"
-"# occurrence of policy violation. You can specify 60 to limit notifycation\n"
-"# to once per a minute, 3600 to limit notifycation to once per an hour.\n"
+"# occurrence of policy violation. You can specify 60 to limit notification\n"
+"# to once per a minute, 3600 to limit notification to once per an hour.\n"
 "# You can specify 0 to unlimit, but notifying of every policy violation\n"
 "# events (e.g. sending a mail) might annoy you because policy violation\n"
 "# can occur in clusters if once occurred.\n"
